Skip to content
KernelIndex
Search⌘K

submission 750300

Bhuminjay Soni · python · License unknown

Use it

Vendorable · source mirrored · license unknownView source →

No package. Vendor the mirrored source: 27 lines, June 9 Researcher Reciprocity License v1.0.

submission_triton.py
curl "https://kernelindex.com/api/v1/implementations/kernelbot-vectoradd-v2-750300?include=source"
interfacepython
Compatibility
measured onNVIDIA A100
declared hardwareNVIDIA A100
architecturessm_80
dtypesfp16

Benchmark evidence

1 measurement across 1 GPU, fastest first.

Operation / workload
Hardware
Latency
Rank
Observed
FP16 vector additionsuite of 5 cases
NVIDIA A100
910.5µs
#17 of 87
2026-04-06

Reported · How evidence levels are derived →

Source and license

sourceavailable
revision digestsha256:49b248fe02737a22ad2b535a2ba4f272bb09a64e6d0e81c4352d50c876b78d7b
license declaredunknown
license concludedunknown
authorsBhuminjay Soni
imported2026-08-15

Kernel source

submission_triton.py27 lines
# submission.py
import torch
import triton
import triton.language as tl
from task import input_t, output_t


@triton.jit
def vecadd_kernel(
    A_ptr, B_ptr, C_ptr,
    N,
    BLOCK_SIZE: tl.constexpr,
):
    idx = tl.program_id(0) * BLOCK_SIZE + tl.arange(0, BLOCK_SIZE)
    mask = idx < N
    a = tl.load(A_ptr + idx, mask=mask)
    b = tl.load(B_ptr + idx, mask=mask)
    tl.store(C_ptr + idx, a + b, mask=mask)


def custom_kernel(data: input_t) -> output_t:
    A, B, C = data
    N = A.numel()
    BLOCK_SIZE = 1024
    grid = ((N + BLOCK_SIZE - 1) // BLOCK_SIZE,)
    vecadd_kernel[grid](A, B, C, N, BLOCK_SIZE=BLOCK_SIZE)
    return C

Source code from GPU Mode and the KernelBot dataset · June 9 Researcher Reciprocity License v1.0

Best evidence level for this revision: reported

JSON